# vim: set sw=4 ts=4 et nu:

%define soname 0

Name:               mpfc
Version:            1.3.8.1
Release:            0.pm.1.2
Summary:            Music Player for Linux Console
# http://prdownloads.sourceforge.net/mpfc/mpfc-%{version}.tar.gz
Source:             mpfc-%{version}.tar.bz2
Source1:            mpfc.desktop
# pbleser: use getaddrinfo() instead of gethostbyname() as the former also supports IPv6
Patch1:             mpfc-getaddrinfo.patch
# pbleser: fix missing standard library include(s)
Patch2:             mpfc-fix_missing_std_headers.patch
# pbleser: fix missing includes and declarations from internal code
Patch3:             mpfc-fix_missing_includes.patch
Source99:           mpfc-rpmlintrc
URL:                http://sourceforge.net/projects/mpfc/
Group:              Productivity/Multimedia/Sound/Players
License:            GNU General Public License version 3 (GPL v3)
BuildRoot:          %{_tmppath}/build-%{name}-%{version}
BuildRequires:      ncurses-devel
BuildRequires:      libicu-devel
BuildRequires:      libmad-devel
BuildRequires:      alsa-devel
BuildRequires:      flac-devel
BuildRequires:      libogg-devel libvorbis-devel
%if 0%{?suse_version} >= 1140
BuildRequires:      gpm-devel
%else
BuildRequires:      gpm
%endif
BuildRequires:      bison flex
BuildRequires:      gcc make glibc-devel pkgconfig
BuildRequires:      autoconf automake libtool
BuildRequires:      update-desktop-files
Requires:           libmpfc%{soname} = %{version}

%description
MPFC is a full-featured curses-based music player for Linux. It supports the
standard playlist paradigm and a number of input file formats through loadable
modules (plugins).

%package -n libmpfc%{soname}
Summary:            Music Player for Linux Console Library
Group:              System/Libraries

%description -n libmpfc%{soname}
MPFC is a full-featured curses-based music player for Linux. It supports the
standard playlist paradigm and a number of input file formats through loadable
modules (plugins).

This package contains the libmpfc library, that is used by mpfc and its
plugins.

%package -n libmpfc-devel
Summary:            Development environment for mpfc plugins
Group:              Development/Libraries/C and C++
Requires:           libmpfc%{soname} = %{version}

%description -n libmpfc-devel
MPFC is a full-featured curses-based music player for Linux. It supports the
standard playlist paradigm and a number of input file formats through loadable
modules (plugins).

This package contains the necessary environment to build mpfc plugins.

%prep
%setup -q
%patch1
%patch2
%patch3

%build
CFLAGS="%{optflags} -Wall -Wno-unused -I/usr/include/ncursesw" \
%configure \
    --disable-rpath \
    --enable-gpm \
    --enable-mp3 \
    --enable-flac \
    --enable-cue \
    --enable-audiocd \
    --enable-ogg \
    --enable-alsa \
    --enable-wav \
    --enable-disk_writer \
    --enable-oss

%__make %{?_smp_flags}

%install
%makeinstall

find "%{buildroot}%{_libdir}" -type f \( -name '*.a' -o -name '*.la' \) -exec %__rm {} \;

for p in general charset effect; do
    # using mkdir here on purpose, as mkdir_p and install -d fail silently if the
    # directory already exists, but we want the build to fail if mpfc suddenly has
    # plugins in there (to change the spec file accordingly)
    %__mkdir "%{buildroot}%{_libdir}/mpfc/$p"
done

%__install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%suse_update_desktop_file -r "%{name}" AudioVideo Player

%find_lang "%{name}"

%post   -n libmpfc%{soname} -p /sbin/ldconfig
%postun -n libmpfc%{soname} -p /sbin/ldconfig

%post
%install_info --info-dir="%{_infodir}" "%{_infodir}/mpfc.info.%{ext_info}"

%postun
%install_info_delete --info-dir="%{_infodir}" "%{_infodir}/mpfc.info.%{ext_info}"

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files -f "%{name}.lang"
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING NEWS README
%config(noreplace) %{_sysconfdir}/mpfcrc
%{_bindir}/mpfc
%dir %{_libdir}/mpfc
%dir %{_libdir}/mpfc/input
%{_libdir}/mpfc/input/libaudiocd.so
%{_libdir}/mpfc/input/libaudiocd.so.*
%{_libdir}/mpfc/input/libcue.so
%{_libdir}/mpfc/input/libcue.so.*
%{_libdir}/mpfc/input/libflac.so
%{_libdir}/mpfc/input/libflac.so.*
%{_libdir}/mpfc/input/libmp3.so
%{_libdir}/mpfc/input/libmp3.so.*
%{_libdir}/mpfc/input/libogg_vorbis.so
%{_libdir}/mpfc/input/libogg_vorbis.so.*
%{_libdir}/mpfc/input/libwav.so
%{_libdir}/mpfc/input/libwav.so.*
%dir %{_libdir}/mpfc/output
%{_libdir}/mpfc/output/libalsa.so
%{_libdir}/mpfc/output/libalsa.so.*
%{_libdir}/mpfc/output/libdisk_writer.so
%{_libdir}/mpfc/output/libdisk_writer.so.*
%{_libdir}/mpfc/output/liboss.so
%{_libdir}/mpfc/output/liboss.so.*
%dir %{_libdir}/mpfc/general
%dir %{_libdir}/mpfc/charset
%dir %{_libdir}/mpfc/effect
%doc %{_infodir}/mpfc.info%{ext_info}
%doc %{_mandir}/man1/mpfc.1%{ext_man}
%{_datadir}/applications/%{name}.desktop

%files -n libmpfc%{soname}
%defattr(-,root,root)
%{_libdir}/libmpfc.so.%{soname}
%{_libdir}/libmpfc.so.%{soname}.*
%{_libdir}/libmpfcwnd.so.%{soname}
%{_libdir}/libmpfcwnd.so.%{soname}.*

%files -n libmpfc-devel
%defattr(-,root,root)
%{_includedir}/mpfc
%{_libdir}/libmpfc.so
%{_libdir}/libmpfcwnd.so
%{_libdir}/pkgconfig/mpfc.pc

%changelog
* Sun Mar 13 2011 pascal.bleser@opensuse.org
- initial version (1.3.8)
